Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(924)

Unified Diff: sql/connection.h

Issue 2545173002: [tracing] Remove MemoryAllocatorDump::process_memory_dump (Closed)
Patch Set: Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sql/connection.h
diff --git a/sql/connection.h b/sql/connection.h
index 20ea3cd5101b199f20be8c143403bec9fd42f3dd..639c333ed4de7cc6e90d7a3605e7e7deb95135ba 100644
--- a/sql/connection.h
+++ b/sql/connection.h
@@ -29,7 +29,7 @@ namespace base {
class FilePath;
class HistogramBase;
namespace trace_event {
-class MemoryAllocatorDump;
+class ProcessMemoryDump;
}
}
@@ -254,8 +254,9 @@ class SQL_EXPORT Connection {
// get diagnostic information about the database.
std::string GetDiagnosticInfo(int extended_error, Statement* statement);
- // Reports memory usage into provided memory dump.
- bool ReportMemoryUsage(base::trace_event::MemoryAllocatorDump* mad);
+ // Reports memory usage into provided memory dump with the given name.
+ bool ReportMemoryUsage(base::trace_event::ProcessMemoryDump* pmd,
+ const std::string& dump_name);
// Initialization ------------------------------------------------------------

Powered by Google App Engine
This is Rietveld 408576698